@@ -8,13 +8,12 @@
  * @package  Kolab_Storage
  * @author   Gunnar Wrobel <wrobel@pardus.de>
  * @license  http://www.horde.org/licenses/lgpl21 LGPL 2.1
- * @link     http://pear.horde.org/index.php?package=Kolab_Storage
  */
 
 /**
  * The Horde_Kolab_Storage_Folder_Namespace_Element:: class represents a namespace type.
  *
- * Copyright 2010-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2010-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -23,7 +22,6 @@
  * @package  Kolab_Storage
  * @author   Gunnar Wrobel <wrobel@pardus.de>
  * @license  http://www.horde.org/licenses/lgpl21 LGPL 2.1
- * @link     http://pear.horde.org/index.php?package=Kolab_Storage
  */
 abstract class Horde_Kolab_Storage_Folder_Namespace_Element
 {
@@ -139,7 +137,7 @@ abstract class Horde_Kolab_Storage_Folder_Namespace_Element
      */
     public function getSubpath($name)
     {
-        return join($this->_subpath($name), $this->_delimiter);
+        return implode($this->_delimiter, $this->_subpath($name));
     }
 
     /**
@@ -153,7 +151,7 @@ abstract class Horde_Kolab_Storage_Folder_Namespace_Element
     {
         $path = explode($this->_delimiter, $name);
         array_pop($path);
-        return join($path, $this->_delimiter);
+        return implode($this->_delimiter, $path);
     }
 
     /**
