@@ -9,13 +9,12 @@
  * @subpackage UnitTests
  * @author     Gunnar Wrobel <wrobel@pardus.de>
  * @license    http://www.horde.org/licenses/lgpl21 LGPL 2.1
- * @link       http://pear.horde.org/index.php?package=Kolab_Storage
  */
 
 /**
  * Tests the modification of existing Kolab mime messages.
  *
- * Copyright 2012-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2012-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -25,7 +24,6 @@
  * @subpackage UnitTests
  * @author     Gunnar Wrobel <wrobel@pardus.de>
  * @license    http://www.horde.org/licenses/lgpl21 LGPL 2.1
- * @link       http://pear.horde.org/index.php?package=Kolab_Storage
  */
 class Horde_Kolab_Storage_ComponentTest_Data_Object_Message_ModifiedTest
 extends PHPUnit_Framework_TestCase
@@ -77,12 +75,12 @@ extends PHPUnit_Framework_TestCase
             ),
             $result
         );
-        $this->assertEquals(
+        $this->assertStringMatchesFormat(
             'From: user
 To: user
 Date: 
 Subject: ABC1234
-User-Agent: Horde::Kolab::Storage v@version@
+User-Agent: Horde::Kolab::Storage v%s
 MIME-Version: 1.0
 X-Kolab-Type: application/x-vnd.kolab.note
 Content-Type: multipart/mixed; boundary="";
@@ -110,7 +108,7 @@ Content-Disposition: inline; x-kolab-type=xml; filename=kolab.xml
   <creation-date></creation-date>
   <last-modification-date></last-modification-date>
   <sensitivity>public</sensitivity>
-  <product-id>Horde_Kolab_Format_Xml-@version@ (api version: 2)</product-id>
+  <product-id>Horde_Kolab_Format_Xml-%s (api version: 2)</product-id>
   <summary>NEW</summary>
   <x-test>other client</x-test>
   <background-color>#000000</background-color>
