@@ -9,13 +9,12 @@
  * @subpackage UnitTests
  * @author     Gunnar Wrobel <wrobel@pardus.de>
  * @license    http://www.horde.org/licenses/lgpl21 LGPL 2.1
- * @link       http://pear.horde.org/index.php?package=Kolab_Storage
  */
 
 /**
  * Tests the creation of new Kolab mime messages.
  *
- * Copyright 2012-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2012-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -25,7 +24,6 @@
  * @subpackage UnitTests
  * @author     Gunnar Wrobel <wrobel@pardus.de>
  * @license    http://www.horde.org/licenses/lgpl21 LGPL 2.1
- * @link       http://pear.horde.org/index.php?package=Kolab_Storage
  */
 class Horde_Kolab_Storage_ComponentTest_Data_Object_Message_NewTest
 extends PHPUnit_Framework_TestCase
@@ -76,12 +74,12 @@ extends PHPUnit_Framework_TestCase
             ),
             $result
         );
-        $this->assertEquals(
+        $this->assertStringMatchesFormat(
             'From: user
 To: user
 Date: 
 Subject: ABC1234
-User-Agent: Horde_Kolab_Storage @version@
+User-Agent: Horde_Kolab_Storage %s
 MIME-Version: 1.0
 X-Kolab-Type: application/x-vnd.kolab.note
 Content-Type: multipart/mixed; name="Kolab Groupware Data";
@@ -107,7 +105,7 @@ Content-Disposition: inline; x-kolab-type=xml; filename=kolab.xml
   <creation-date></creation-date>
   <last-modification-date></last-modification-date>
   <sensitivity>public</sensitivity>
-  <product-id>Horde_Kolab_Format_Xml-@version@ (api version: 2)</product-id>
+  <product-id>Horde_Kolab_Format_Xml-%s (api version: 2)</product-id>
   <summary>TEST</summary>
   <background-color>#000000</background-color>
   <foreground-color>#ffff00</foreground-color>
